@@ -9,10 +9,6 @@ from django.template import RequestContext
 def as_json(func):
     def decorator(request, *ar, **kw):
         output = func(request, *ar, **kw)
-
-        if not isinstance(output, dict):
-            return output
-
         return HttpResponse(json.dumps(output), 'application/json')
     return decorator
 
@@ -21,12 +17,8 @@ def as_jsonp(functionCallKey='callback'):
     def decorator(func):
         def wrapper(request, *ar, **kw):
             output = func(request, *ar, **kw)
-
-            if not isinstance(output, dict):
-                return output
-
             return HttpResponse(
-                "%s(%s)" % (request.GET.get(functionCallKey),
+                "%s(%s)" % (request.GET.get(functionCallKey, functionCallKey),
                             json.dumps(output)),
                 'application/json'
             )
